Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DisplayClaims ¶
type DisplayClaims struct {
// TitleInfo contains the information about the authenticated title
// as claimed by the token.
TitleInfo TitleInfo `json:"xti"`
}
DisplayClaims holds the metadata embedded in a title token.
type TitleInfo ¶
type TitleInfo struct {
// TitleID is the Xbox Live title ID, represented as a decimal integer
// encoded in string form.
TitleID string `json:"tid"`
}
TitleInfo holds the identity information for a title as claimed by a Token.
type Token ¶
type Token = internal.Token[DisplayClaims]
Token is an XAST (Xbox Authentication Services for Titles) token that authenticates a title on Xbox Live. A title corresponds to a specific game or application registered with Xbox Live.
Click to show internal directories.
Click to hide internal directories.